import 'package:flutter/material.dart';
import '../../fx_extensions.dart';
import '../../fx_utilities.dart';

/// Get empty state widget
class FxEmptyState extends StatelessWidget {
  ///Create custom empty state screen
  FxEmptyState({
    required this.title,
    required this.asset,
    this.subTitle,
    this.subtitleTextStyle,
    this.titleTextStyle,
    this.backgroundColor,
    this.imageHeight,
    this.imageWidth,
    this.button,
  });

  /// Sets image to [FxEmptyState]
  final Widget asset;

  /// Sets image height
  final double? imageHeight;

  /// Sets image width
  final double? imageWidth;

  /// Sets title to [FxEmptyState]
  final String title;

  /// Sets subTitle to [FxEmptyState]
  final String? subTitle;

  /// Sets style to subtitle
  final TextStyle? subtitleTextStyle;

  /// Sets style to title
  final TextStyle? titleTextStyle;

  /// Sets background color
  final Color? backgroundColor;

  /// Add callable button
  final Widget? button;

  @override
  Widget build(BuildContext context) => Container(
        width: context.width,
        height: context.height,
        padding: FxPadding.p32,
        color: backgroundColor ?? Colors.transparent,
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          crossAxisAlignment: CrossAxisAlignment.center,
          children: <Widget>[
            Container(
              height: imageHeight ?? context.height * .4,
              width: imageWidth ?? context.width * .6,
              child: asset,
            ).pb24,
            Text(title)
                .blueGray500
                .xl2
                .bold
                .wideLetter
                .textStyle(style: titleTextStyle),
            Text(subTitle ?? '')
                .blueGray500
                .md
                .widerLetter
                .textStyle(style: subtitleTextStyle)
                .hide(subTitle == null),
            SizedBox(child: button).pt20,
          ],
        ),
      );
}
