import 'package:customize/customize.dart';
import 'package:flutter/material.dart';

class FxTextFormField extends StatelessWidget {
  const FxTextFormField({
    required this.hintText,
    Key? key,
    this.label,
    this.fieldColor,
    this.leadingIcon,
    this.isSecure = false,
    this.borderRadius,
    this.maxLines,
    this.keyboardType,
    this.border = false,
    this.controller,
  }) : super(key: key);

  final String? label;
  final String hintText;
  final Color? fieldColor;
  final IconData? leadingIcon;
  final bool isSecure;
  final BorderRadiusGeometry? borderRadius;
  final int? maxLines;
  final TextInputType? keyboardType;
  final bool border;
  final TextEditingController? controller;

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        Text(
          label ?? '',
          style: TextStyle(fontSize: 18, color: FxColors.textColor),
        ).pb8.hide(label == null),
        Container(
          padding: FxPadding.px20,
          decoration: BoxDecoration(
            color: fieldColor ?? FxColors.textFieldColor,
            border: Border.all(
                color: FxColors.blueGray300,
                style: border ? BorderStyle.solid : BorderStyle.none),
            borderRadius: borderRadius ?? FxRadius.all(10),
          ),
          child: Row(
            children: <Widget>[
              Expanded(
                child: TextFormField(
                  controller: controller,
                  decoration: InputDecoration(
                    icon: Icon(leadingIcon).hide(leadingIcon == null),
                    hintText: hintText,
                    border: InputBorder.none,
                  ),
                  keyboardType: keyboardType,
                  obscureText: isSecure,
                  maxLines: maxLines ?? 1,
                ),
              ),
            ],
          ),
        ),
      ],
    );
  }
}
